@@ -1,27 +1,18 @@
-//  
-//  Copyright (c) 1994, 1995 by Mike Romberg ( romberg@fsl.noaa.gov )
+//
+//  Copyright (c) 1994, 1995, 2006 by Mike Romberg ( mike.romberg@noaa.gov )
 //
 //  This file may be distributed under terms of the GPL
 //
-//
-// $Id$
-//
 
 #ifndef _Host_h
 #define _Host_h
 
-#define HOST_H_CVSID "$Id$"
-
 #include <sys/types.h>
 #include <sys/socket.h>
 #include <netinet/in.h>
 #include <netdb.h>
 #include <arpa/inet.h>
-#ifdef HAVE_IOSTREAM
 #include <iostream>
-#else
-#include <iostream.h>
-#endif
 #include "bool.h"
 
 class Host {
@@ -58,8 +49,8 @@ public:
   int addrLength(void) const { return _hent.h_length; }
 
   int numAddresses(void) const { return _numAddresses; }
-  struct in_addr *address(int num) const { 
-    return (in_addr *)_hent.h_addr_list[num]; 
+  struct in_addr *address(int num) const {
+    return (in_addr *)_hent.h_addr_list[num];
   }
 
   // Linux will choke and die inside of inet_ntoa() when
