@@ -3,16 +3,12 @@
 //
 //  This file may be distributed under terms of the GPL
 //
-//
-// $Id$
-//
+
 #ifndef _Xrm_h
 #define _Xrm_h
 
 #include "bool.h"
 
-#define XRM_H_CVSID "$Id$"
-
 #include <X11/Xlib.h>
 #include <X11/Xresource.h>
 
@@ -34,7 +30,7 @@ public:
 private:
   XrmDatabase _db;
   XrmClass _class, _instance;
-  char* _display_name;  //  Used solely for getting the display's resources.
+  const char* _display_name;  //  Used solely for getting the display's resources.
 
   //void getArgs(int argc, char **argv);
   static Bool enumCB(XrmDatabase *, XrmBindingList bindings,
