@@ -2,7 +2,7 @@
 //  Copyright (c) 1994, 1995 by Mike Romberg ( romberg@fsl.noaa.gov )
 //
 //  NetBSD port:  
-//  Copyright (c) 1995, 1996, 1997 by Brian Grayson (bgrayson@ece.utexas.edu)
+//  Copyright (c) 1995, 1996, 1997-2002 by Brian Grayson (bgrayson@netbsd.org)
 //
 //  This file was originally written by Brian Grayson for the NetBSD and
 //    xosview projects.
@@ -15,8 +15,7 @@
 //    should have received.  If not, contact one of the xosview
 //    authors for a copy.
 //
-// $Id$
-//
+
 #include <stdlib.h>		//  For atoi().  BCG
 #include "general.h"
 #include "memmeter.h"
@@ -29,9 +28,6 @@
 # include <sys/vmmeter.h>
 #endif
 
-CVSID("$Id$");
-CVSID_DOT_H(MEMMETER_H_CVSID);
-
 MemMeter::MemMeter( XOSView *parent )
 #ifdef  XOSVIEW_FREEBSD
 : FieldMeterGraph( parent, 5, "MEM", "ACT/INACT/WRD/CA/FRE" ) {
@@ -90,9 +86,16 @@ void MemMeter::getmeminfo (void) {
   /*  Initialize total_ to 0.0.  FreeBSD will then add some to
    *  this, and later we'll add all the common fields to this.  */
   total_ = 0.0;
-#if defined(UVM) & defined(XOSVIEW_NETBSD)
+#if defined(UVM) && (defined(XOSVIEW_NETBSD) || defined(XOSVIEW_OPENBSD))
+#ifdef VM_UVMEXP2
+  int params[] = {CTL_VM, VM_UVMEXP2};
+  struct uvmexp_sysctl kvm_uvm_exp;
+  size_t kvm_uvm_exp_size = sizeof (kvm_uvm_exp);
+  sysctl (params, 2, &kvm_uvm_exp, &kvm_uvm_exp_size, NULL, 0);
+#else
   struct uvmexp kvm_uvm_exp;
   BSDGetUVMPageStats(&kvm_uvm_exp);
+#endif
   int pgsize = kvm_uvm_exp.pagesize;
   fields_[0] = kvm_uvm_exp.active*pgsize;
   fields_[1] = kvm_uvm_exp.inactive*pgsize;
