@@ -2,7 +2,7 @@
 //  Copyright (c) 1994, 1995 by Mike Romberg ( romberg@fsl.noaa.gov )
 //
 //  NetBSD port:  
-//  Copyright (c) 1995, 1996, 1997 by Brian Grayson (bgrayson@ece.utexas.edu)
+//  Copyright (c) 1995, 1996, 1997-2002 by Brian Grayson (bgrayson@netbsd.org)
 //
 //  This file was written by Brian Grayson for the NetBSD and xosview
 //    projects.
@@ -12,13 +12,10 @@
 //    should have received.  If not, contact one of the xosview
 //    authors for a copy.
 //
-// $Id$
-//
+
 #ifndef _NETMETER_H_
 #define _NETMETER_H_
 
-#define NETMETER_H_CVSID "$Id$"
-
 #include "fieldmetergraph.h"
 #include "timer.h"
 
@@ -33,14 +30,20 @@ public:
   void checkevent( void );
 
   void checkResources( void );
+
+  void BSDGetNetInOut (long long * inbytes, long long * outbytes);
 protected:
   float netBandwidth_;
+  std::string netIface_;
 
 private:
   //  NetBSD:  Use long long, so we won't run into problems after 4 GB
   //  has been transferred over the net!
   long long _lastBytesIn, _lastBytesOut;
 
+  //  Did the meter initialize properly?
+  bool kernelHasStats_;
+
   void adjust(void);
 };
 
