@@ -1,31 +1,18 @@
-//  
-//  Copyright (c) 1994, 1995 by Mike Romberg ( romberg@fsl.noaa.gov )
+//
+//  Copyright (c) 1994, 1995, 2006 by Mike Romberg ( mike.romberg@noaa.gov )
 //
 //  This file may be distributed under terms of the GPL
 //
-//
-// $Id$
-//
-#ifdef HAVE_IOSTREAM
+
 #include <iostream>
-#else
-#include <iostream.h>
-#endif
-#ifdef HAVE_FSTREAM
 #include <fstream>
-#else
-#include <fstream.h>
-#endif
 #include <stdlib.h>
 #include "snprintf.h"
 #include "general.h"
 #include "fieldmeter.h"
 #include "xosview.h"
 
-CVSID("$Id$");
-CVSID_DOT_H(FIELDMETER_H_CVSID);
-
-FieldMeter::FieldMeter( XOSView *parent, int numfields, const char *title, 
+FieldMeter::FieldMeter( XOSView *parent, int numfields, const char *title,
                         const char *legend, int docaptions, int dolegends,
                         int dousedlegends )
 : Meter(parent, title, legend, docaptions, dolegends, dousedlegends){
@@ -132,25 +119,30 @@ void FieldMeter::draw( void ){
   parent_->drawRectangle( x_ - 1, y_ - 1, width_ + 2, height_ + 2 );
   if ( dolegends_ ){
     parent_->setForeground( textcolor_ );
-    
+
     int offset;
     if ( dousedlegends_ )
       offset = parent_->textWidth( "XXXXXXXXX" );
     else
       offset = parent_->textWidth( "XXXXX" );
-    
+
     parent_->drawString( x_ - offset + 1, y_ + height_, title_ );
-    if(docaptions_)
-      drawlegend();
   }
 
+  drawlegend();
   drawfields( 1 );
 }
 
 void FieldMeter::drawlegend( void ){
   char *tmp1, *tmp2, buff[100];
   int n, x = x_;
-  
+
+  if (!docaptions_ || !dolegends_)
+    return;
+
+  parent_->clear( x_, y_ - 5 - parent_->textHeight(),
+                  width_ + 5, parent_->textHeight() + 4 );
+
   tmp1 = tmp2 = legend_;
   for ( int i = 0 ; i < numfields_ ; i++ ){
     n = 0;
@@ -176,7 +168,7 @@ void FieldMeter::drawlegend( void ){
 
 void FieldMeter::drawused( int manditory ){
   if ( !manditory )
-    if ( (lastused_ == used_) )
+    if ( lastused_ == used_ )
       return;
 
   parent_->setStippleN(0);	/*  Use all-bits stipple.  */
@@ -212,7 +204,7 @@ void FieldMeter::drawused( int manditory ){
 	{scale='M'; scaled_used = used_/1024/1024;}
     else if (used_ >= 999.5)
 	{scale='K'; scaled_used = used_/1024;}
-    else {scale=' '; scaled_used = used_;}
+    else {scale='\0'; scaled_used = used_;}
       /*  For now, we can only print 3 characters, plus the optional
        *  suffix, without overprinting the legends.  Thus, we can
        *  print 965, or we can print 34, but we can't print 34.7 (the
@@ -223,23 +215,28 @@ void FieldMeter::drawused( int manditory ){
       snprintf (buf, 10, "-");
     else if (scaled_used == 0.0)
       snprintf (buf, 10, "0");
-    else if (scaled_used < 9.95)  //  9.95 or above would get
-				  //  rounded to 10.0, which is too wide.
-      snprintf (buf, 10, "%.1f%c", scaled_used, scale);
-    /*  We don't need to check against 99.5 -- it all gets %.0f.  */
-    /*else if (scaled_used < 99.5)*/
-      /*snprintf (buf, 10, "%.0f%c", scaled_used, scale);*/
-    else 
-      snprintf (buf, 10, "%.0f%c", scaled_used, scale);
+    else if (scaled_used < 9.95) {
+      //  9.95 or above would get
+      //  rounded to 10.0, which is too wide.
+      if (scale)
+	snprintf (buf, 10, "%.1f%c", scaled_used, scale);
+      else
+	snprintf (buf, 10, "%.1f", scaled_used);
+    } else {
+      if (scale)
+        snprintf (buf, 10, "%.0f%c", scaled_used, scale);
+      else
+        snprintf (buf, 10, "%.0f", scaled_used);
+    }
   }
   else {
     snprintf( buf, 10, "%.1f", used_ );
   }
 
-  parent_->clear( x_ - xoffset, y_ + height_ - parent_->textHeight(), 
+  parent_->clear( x_ - xoffset, y_ + height_ - parent_->textHeight(),
 		 xoffset - onechar / 2, parent_->textHeight() + 1 );
   parent_->setForeground( usedcolor_ );
-  parent_->drawString( x_ - (strlen( buf ) + 1 ) * onechar + 2, 
+  parent_->drawString( x_ - (strlen( buf ) + 1 ) * onechar + 2,
 		      y_ + height_, buf );
 
   lastused_ = used_;
@@ -250,7 +247,7 @@ void FieldMeter::drawfields( int manditory ){
 
   if ( total_ == 0 )
     return;
-  
+
   for ( int i = 0 ; i < numfields_ ; i++ ){
     /*  Look for bogus values.  */
     if (fields_[i] < 0.0) {
@@ -265,7 +262,7 @@ void FieldMeter::drawfields( int manditory ){
 	  "will not be displayed.\n", name());
     }
 
-    twidth = (int) ((width_ * (float) fields_[i]) / total_); 
+    twidth = (int) ((width_ * (float) fields_[i]) / total_);
 //    twidth = (int)((fields_[i] * width_) / total_);
     if ( (i == numfields_ - 1) && ((x + twidth) != (x_ + width_)) )
       twidth = width_ + x_ - x;
@@ -297,7 +294,7 @@ void FieldMeter::setNumFields(int n){
   delete[] colors_;
   delete[] lastvals_;
   delete[] lastx_;
-  fields_ = new float[numfields_];
+  fields_ = new double[numfields_];
   colors_ = new unsigned long[numfields_];
   lastvals_ = new int[numfields_];
   lastx_ = new int[numfields_];
