@@ -8,8 +8,6 @@
 //  Modifications from FieldMeterDecay class done in Oct. 1998
 //    by Scott McNab ( jedi@tartarus.uwa.edu.au )
 //
-// $Id$
-//
 
 // In order to use the FieldMeterGraph class in place of a FieldMeter class in
 // a meter file (say, cpumeter.cc), make the following changes:
@@ -24,20 +22,13 @@
 //   5.  Make the checkResources () function in the meter set the
 //	 useGraph_ variable according to the, e.g., xosview*cpuGraph resource.
 
-#ifdef HAVE_FSTREAM
 #include <fstream>
-#else
-#include <fstream.h>
-#endif
 #include <math.h>		//  For fabs()
 #include "general.h"
 #include "fieldmeter.h"
 #include "fieldmetergraph.h"
 #include "xosview.h"
 
-CVSID("$Id$");
-CVSID_DOT_H(FIELDMETERGRAPH_H_CVSID);
-
 FieldMeterGraph::FieldMeterGraph( XOSView *parent,
                 int numfields, const char *title,
                 const char *legend, int docaptions, int dolegends,
