@@ -1,6 +1,6 @@
-//  
-//  Original FieldMeter class is Copyright (c) 1994 by Mike Romberg 
-//    ( romberg@fsl.noaa.gov )
+//
+//  Original FieldMeter class is Copyright (c) 1994, 2006 by Mike Romberg
+//    ( mike.romberg@noaa.gov )
 //
 //  Modifications from FieldMeter class done in Oct. 1995
 //    by Brian Grayson ( bgrayson@netbsd.org )
@@ -12,18 +12,16 @@
 #ifndef _FIELDMETERGRAPH_H_
 #define _FIELDMETERGRAPH_H_
 
-#define FIELDMETERGRAPH_H_CVSID "$Id$"
-
 #include "meter.h"
 #include "fieldmeterdecay.h"
 
 class FieldMeterGraph : public FieldMeterDecay {
 public:
   FieldMeterGraph( XOSView *parent, int numfields,
-              const char *title = "", const char *legend = "", 
+              const char *title = "", const char *legend = "",
               int docaptions = 0, int dolegends = 0, int dousedlegends = 0 );
   virtual ~FieldMeterGraph( void );
-  
+
   virtual void drawfields( int manditory = 0 );
 
   virtual void checkResources( void );
