@@ -3,12 +3,11 @@
 //
 //  This file may be distributed under terms of the GPL
 //
-//
-// $Id$
-//
+
 #include "cpumeter.h"
 #include "xosview.h"
 #include <fstream>
+#include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 #include <string>
@@ -19,10 +18,10 @@ static const char STATFILENAME[] = "/proc/stat";
 #define MAX_PROCSTAT_LENGTH 4096
 
 CPUMeter::CPUMeter(XOSView *parent, const char *cpuID)
-: FieldMeterGraph( parent, 7, toUpper(cpuID), "US/NI/SY/ID/WA/HI/SI" ) {
+: FieldMeterGraph( parent, 9, toUpper(cpuID), "USR/NICE/SYS/SI/HI/WIO/GST/ST/IDLE" ) {
   _lineNum = findLine(cpuID);
   for ( int i = 0 ; i < 2 ; i++ )
-    for ( int j = 0 ; j < 7 ; j++ )
+    for ( int j = 0 ; j < 9 ; j++ )
       cputime_[i][j] = 0;
   cpuindex_ = 0;
 
@@ -37,10 +36,12 @@ void CPUMeter::checkResources( void ){
   setfieldcolor( 0, parent_->getResource( "cpuUserColor" ) );
   setfieldcolor( 1, parent_->getResource( "cpuNiceColor" ) );
   setfieldcolor( 2, parent_->getResource( "cpuSystemColor" ) );
-  setfieldcolor( 3, parent_->getResource( "cpuFreeColor" ) );
-  setfieldcolor( 4, parent_->getResource( "cpuWaitColor" ) );
-  setfieldcolor( 5, parent_->getResource( "cpuInterruptColor" ) );
-  setfieldcolor( 6, parent_->getResource( "cpuSoftIntColor" ) );
+  setfieldcolor( 3, parent_->getResource( "cpuSInterruptColor" ) );
+  setfieldcolor( 4, parent_->getResource( "cpuInterruptColor" ) );
+  setfieldcolor( 5, parent_->getResource( "cpuWaitColor" ) );
+  setfieldcolor( 6, parent_->getResource( "cpuGuestColor" ) );
+  setfieldcolor( 7, parent_->getResource( "cpuStolenColor" ) );
+  setfieldcolor( 8, parent_->getResource( "cpuFreeColor" ) );
   priority_ = atoi (parent_->getResource( "cpuPriority" ) );
   dodecay_ = parent_->isResourceTrue( "cpuDecay" );
   useGraph_ = parent_->isResourceTrue( "cpuGraph" );
@@ -75,16 +76,24 @@ void CPUMeter::getcputime( void ){
 	      >>cputime_[cpuindex_][3]
 	      >>cputime_[cpuindex_][4]
 	      >>cputime_[cpuindex_][5]
-	      >>cputime_[cpuindex_][6];
+	      >>cputime_[cpuindex_][6]
+	      >>cputime_[cpuindex_][7]
+	      >>cputime_[cpuindex_][8];
 
   int oldindex = (cpuindex_+1)%2;
-  for ( int i = 0 ; i < 7 ; i++ ){
-    fields_[i] = cputime_[cpuindex_][i] - cputime_[oldindex][i];
-    total_ += fields_[i];
+  for ( int i = 0 ; i < 9 ; i++ ){
+    static int cputime_to_field[9] = { 0, 1, 2, 8, 5, 4, 3, 7, 6 };
+    int field = cputime_to_field[i];
+    fields_[field] = cputime_[cpuindex_][i] - cputime_[oldindex][i];
+    total_ += fields_[field];
   }
 
+  // Guest time already included in user time
+  fields_[0] -= fields_[6];
+  total_ -= fields_[6];
+
   if (total_){
-    setUsed (total_ - fields_[3], total_);
+    setUsed (total_ - fields_[8], total_); // any non-idle time
     cpuindex_ = (cpuindex_ + 1) % 2;
   }
 }
@@ -136,13 +145,10 @@ const char *CPUMeter::cpuStr(int num){
   static char buffer[32];
   std::ostringstream str;
 
-  str << "cpu";
   if (num != 0)
-    str << (num - 1);
-  str << std::ends;
-
-  strncpy(buffer, str.str().c_str(), 32);
-  buffer[31] = '\0';
+    snprintf(buffer, sizeof(buffer), "cpu%d", num - 1);
+  else
+    strcpy(buffer, "cpu");
 
   return buffer;
 }
