@@ -3,9 +3,7 @@
 //
 //  This file may be distributed under terms of the GPL
 //
-//
-// $Id$
-//
+
 #ifndef _CPUMETER_H_
 #define _CPUMETER_H_
 
@@ -25,7 +23,7 @@ public:
   static const char *cpuStr(int num);
 protected:
   int _lineNum;
-  long cputime_[2][7];
+  long long cputime_[2][9];
   int cpuindex_;
 
   void getcputime(void);
