@@ -1,6 +1,6 @@
 //
-//  Copyright (c) 1999 by Thomas Waldmann ( ThomasWaldmann@gmx.de )
-//  based on work of Mike Romberg ( romberg@fsl.noaa.gov )
+//  Copyright (c) 1999, 2006 by Thomas Waldmann ( ThomasWaldmann@gmx.de )
+//  based on work of Mike Romberg ( mike.romberg@noaa.gov )
 //
 //  This file may be distributed under terms of the GPL
 //
@@ -67,7 +67,7 @@ void RAIDMeter::checkResources( void ){
 
 // parser for /proc/mdstat
 
-int RAIDMeter::find1(char *key, char *findwhat, int num1){
+int RAIDMeter::find1(const char *key, const char *findwhat, int num1){
   char buf[80];
   int rc;
   std::ostringstream os;
@@ -78,7 +78,8 @@ int RAIDMeter::find1(char *key, char *findwhat, int num1){
   return rc;
 }
 
-int RAIDMeter::find2(char *key, char *findwhat, int num1, int num2){
+int RAIDMeter::find2(const char *key, const char *findwhat,
+  int num1, int num2){
   char buf[80];
   int rc;
   std::ostringstream os;
