@@ -1,11 +1,8 @@
 //
-//  Copyright (c) 1994, 1995 by Mike Romberg ( romberg@fsl.noaa.gov )
+//  Copyright (c) 1994, 1995, 2006 by Mike Romberg ( mike.romberg@noaa.gov )
 //
 //  This file may be distributed under terms of the GPL
 //
-//
-// $Id$
-//
 
 //
 //  In order to use this new serial meter, xosview needs to be suid root.
@@ -32,10 +29,10 @@ typedef unsigned long long u64;
 
 #include <unistd.h>
 #if defined(GNULIBC) || defined(__GLIBC__)
-#if !defined(__hppa__) && !defined(__mips__)
+#if !defined(__hppa__) && !defined(__mips__) && !defined(__sparc__) && !defined(__sh__)
 #include <sys/io.h>
 #endif
-#if !defined(__alpha__) && !defined(__sparc__) && !defined(__powerpc__) && !defined(__ia64__) && !defined(__hppa__) && !defined(__arm__) && !defined(__mips__)
+#if !defined(__alpha__) && !defined(__sparc__) && !defined(__powerpc__) && !defined(__ia64__) && !defined(__hppa__) && !defined(__arm__) && !defined(__mips__) && !defined(__sh__)
 #include <sys/perm.h>
 #define HAVE_IOPERM
 #endif
@@ -45,7 +42,6 @@ typedef unsigned long long u64;
 #endif
 #endif
 #include <linux/serial.h>
-#include <linux/serial_reg.h>
 
 SerialMeter::SerialMeter( XOSView *parent, Device device )
   : BitMeter( parent, getTitle(device), "LSR bits(0-7), MSR bits(0-7)", 16){
@@ -112,7 +108,7 @@ const char *SerialMeter::getResourceName(Device dev){
 }
 
 unsigned short int SerialMeter::getPortBase(Device dev) const {
-  static char *deviceFile[] = { "/dev/ttyS0",
+  static const char *deviceFile[] = { "/dev/ttyS0",
                                 "/dev/ttyS1",
                                 "/dev/ttyS2",
                                 "/dev/ttyS3",
