@@ -1,19 +1,14 @@
-//  
-//  Copyright (c) 1994, 1995 by Mike Romberg ( romberg@fsl.noaa.gov )
+//
+//  Copyright (c) 1994, 1995, 2006 by Mike Romberg ( mike.romberg@noaa.gov )
 //
 //  This file may be distributed under terms of the GPL
 //
-//
-// $Id$
-//
+
 #include "general.h"
 #include "meter.h"
 #include "xosview.h"
 
-CVSID("$Id$");
-CVSID_DOT_H(METER_H_CVSID);
-
-Meter::Meter( XOSView *parent, const char *title, const char *legend, 
+Meter::Meter( XOSView *parent, const char *title, const char *legend,
               int docaptions, int dolegends, int dousedlegends ) {
   title_ = legend_ = NULL;
   Meter::title( title );
@@ -29,8 +24,10 @@ Meter::Meter( XOSView *parent, const char *title, const char *legend,
 }
 
 Meter::~Meter( void ){
-  delete[] title_;
-  delete[] legend_;
+  if ( title_ )
+        delete[] title_;
+  if ( legend_ )
+        delete[] legend_;
 }
 
 void Meter::checkResources( void ){
@@ -38,7 +35,10 @@ void Meter::checkResources( void ){
 }
 
 void Meter::title( const char *title ){
-  delete[] title_;
+
+  if ( title_ )
+  	delete[] title_;
+
   int len = strlen(title);
   title_ = new char[len + 1];
   strncpy( title_, title, len );
@@ -46,7 +46,10 @@ void Meter::title( const char *title ){
 }
 
 void Meter::legend( const char *legend ){
-  delete[] legend_;
+
+  if ( legend_ )
+	  delete[] legend_;
+
   int len = strlen(legend);
   legend_ = new char[len + 1];
   strncpy( legend_, legend, len );
@@ -60,5 +63,3 @@ void Meter::resize( int x, int y, int width, int height ){
   height_ = (height>=0) ? height : 0; // beware of values < 0 !
   width_ &= ~1;                       // only allow even width_ values
 }
-
-
