@@ -1,6 +1,3 @@
-//
-// $Id$
-//
 #ifndef _XWIN_H_
 #define _XWIN_H_
 
@@ -9,11 +6,13 @@
 #ifdef HAVE_XPM
 #include <X11/xpm.h>
 #endif
-#include <iostream.h>
+#ifdef HAVE_IOSTREAM
+#include <iostream>
+#else
+#include <iostream>
+#endif
 #include <string.h>
 
-#define XWIN_H_CVSID "$Id$"
-
 class XWin;
 class Xrm;
 
@@ -58,9 +57,10 @@ public:
       xgcv.fill_style = FillOpaqueStippled;
       XChangeGC (display_, gc_, GCFillStyle, &xgcv); }
   void setStippleN (int n) {setStipple(stipples_[n]); }
-  Pixmap createPixmap(char* data, unsigned int w, unsigned int h) {
-      return XCreatePixmapFromBitmapData(display_, window_, data, w, h,
-      0, 1, 1); }
+  Pixmap createPixmap(const char* data, unsigned int w, unsigned int h) {
+  return XCreatePixmapFromBitmapData(display_, window_,
+    const_cast<char *>(data), w, h, 0, 1, 1); }
+
   unsigned long foreground( void ) { return fgcolor_; }
   unsigned long background( void ) { return bgcolor_; }
   void resize( int width, int height )
@@ -97,9 +97,9 @@ public:
 
   const char *getResource( const char *name );
   const char *getResourceOrUseDefault( const char *name, const char* defaultVal );
-  const int isResourceTrue( const char* name ) {
+  int isResourceTrue( const char* name ) {
     return (!strncasecmp(getResource(name),"True", 5)); }
-  void dumpResources( ostream &os );
+  void dumpResources(std::ostream &os );
 
 protected:
   class Event {
